@@ -9,6 +9,8 @@ import json
 from pymatgen.core import Composition
 from pymatgen.analysis.phase_diagram import PhaseDiagram
 from pymatgen.util.string import latexify
+from tqdm import tqdm
+
 from piro.data import GASES, GAS_RELEASE, DEFAULT_GAS_PRESSURES
 from piro.mprester import get_mprester
 from piro.reactions import get_reactions
@@ -46,6 +48,7 @@ class SynthesisRoutes:
             are generated using the recommend_routes method (See this method's arguments as well).
             Precursor library, epitaxial match and similarity metrics are precomputed upon instantiation,
             and can be cached.
+
         Args:
             target_entry_id (str): Materials Project entry id for target material
             confine_to_icsd (bool): Use ICSD-sourced entries to find precursors. Defaults to True.
@@ -108,6 +111,8 @@ class SynthesisRoutes:
             if not custom_target_entry:
                 with get_mprester() as mpr:
                     _e = mpr.get_entry_by_material_id(self.target_entry_id)
+                    if isinstance(_e, list):
+                        _e = _e[0]
             else:
                 _e = custom_target_entry
             self.elts = list(_e.composition.as_dict().keys())
@@ -137,16 +142,30 @@ class SynthesisRoutes:
                 self.precursor_library,
                 self.allow_gas_release
             )
-            logger.info(f"Total # of balanced reactions obtained: {len(self.reactions)}")
+            logger.info(f"Total # of balanced reactions obtained: {len(self.reactions_objs)}")
         return self._reactions_objs
 
     def get_mp_entries(self):
         with get_mprester() as mpr:
-            self.entries = mpr.get_entries_in_chemsys(
-                self.elts,
-                inc_structure="final",
-                property_data=["icsd_ids", "formation_energy_per_atom"],
-            )
+            if len(mpr.api_key) == 32:
+                self.entries = mpr.get_entries_in_chemsys(
+                    self.elts,
+                    inc_structure="final",
+                    property_data=["material_id", "formation_energy_per_atom"],
+                )
+                mp_ids = [ent.data['material_id'] for ent in self.entries]
+                provs = mpr.provenance.search(mp_ids, fields=['material_id', 'database_IDs', 'theoretical'])
+                from emmet.core.provenance import Database
+                mp_to_icsd = {str(doc.material_id): doc.database_IDs.get(Database.ICSD)
+                              for doc in provs if not doc.theoretical}
+                for entry in self.entries:
+                    entry.data.update({"icsd_ids": mp_to_icsd.get(entry.data['material_id'])})
+            else:
+                self.entries = mpr.get_entries_in_chemsys(
+                    self.elts,
+                    inc_structure="final",
+                    property_data=["icsd_ids", "formation_energy_per_atom"],
+                )
         for entry in self.entries:
             entry.structure.entry_id = entry.entry_id
         print("Total # of entries found in this chemistry: ", len(self.entries))
@@ -170,6 +189,7 @@ class SynthesisRoutes:
             ]
         else:
             precursor_library = [e for e in self.entries]
+
         if self.confine_to_icsd:
             precursor_library = [i for i in precursor_library if i.data["icsd_ids"]]
 
@@ -207,7 +227,7 @@ class SynthesisRoutes:
         self.precursor_library = precursor_library
 
         print(
-            "Total # of precusors materials obeying the provided filters: ",
+            "Total # of precursors materials obeying the provided filters: ",
             len(precursor_library),
         )
         return self.precursor_library
@@ -222,7 +242,11 @@ class SynthesisRoutes:
 
     def get_reactions_with_energies(self):
         reactions_dict = {}
-        for r in self.reactions_objs:
+        for r in tqdm(
+            self.reactions_objs,
+            desc='Calculating reaction results',
+            total=len(self._reactions_objs)
+        ):
             if r.label in reactions_dict:
                 continue
             else:
@@ -419,7 +443,8 @@ class SynthesisRoutes:
                 go.Scatter(
                     x=_x,
                     y=_y,
-                    line=dict(color="firebrick", width=2)
+                    line=dict(color="firebrick", width=2),
+                    hoverinfo='skip'
                 )
             )
             fig.add_trace(
@@ -428,6 +453,7 @@ class SynthesisRoutes:
                     y=[_y[0], self.topsis()["barrier"].max(), None, _y[-1], _y[-1]],
                     line=dict(color="firebrick", width=2, dash="dash"),
                     connectgaps=False,
+                    hoverinfo='skip'
                 )
             )
 
